==> mx-usb-unmounter_19.04.tar.xz: mx-usb-unmounter/translations/mx-usb-unmounter_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>usbunmounter</name>
    <message>
        <location filename="../usbunmounter.ui" line="27"/>
        <location filename="../usbunmounter.cpp" line="208"/>
        <location filename="../usbunmounter.cpp" line="317"/>
        <location filename="../usbunmounter.cpp" line="324"/>
        <source>MX USB Unmounter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.ui" line="51"/>
        <source>Double-Click to Unmount</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="138"/>
        <source>Volume</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="181"/>
        <source>No Removable Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="205"/>
        <source>Unmounting </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="207"/>
        <source>Other partitions still mounted on device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="276"/>
        <source>Unable to  Unmount, Device in Use</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="316"/>
        <source>About MX USB Unmounter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="317"/>
        <source>Version: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="318"/>
        <source>Quickly Unmount Removable Media</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="320"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="321"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="322"/>
        <location filename="../usbunmounter.cpp" line="324"/>
        <source>License</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> mx-usb-unmounter_23.02.tar.xz: mx-usb-unmounter/translations/mx-usb-unmounter_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko">
<context>
    <name>usbunmounter</name>
    <message>
        <location filename="../usbunmounter.ui" line="27"/>
        <location filename="../usbunmounter.cpp" line="208"/>
        <location filename="../usbunmounter.cpp" line="317"/>
        <location filename="../usbunmounter.cpp" line="324"/>
        <source>MX USB Unmounter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.ui" line="51"/>
        <source>Double-Click to Unmount</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="138"/>
        <source>Volume</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="181"/>
        <source>No Removable Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="205"/>
        <source>Unmounting </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="207"/>
        <source>Other partitions still mounted on device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="276"/>
        <source>Unable to  Unmount, Device in Use</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="316"/>
        <source>About MX USB Unmounter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="317"/>
        <source>Version: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="318"/>
        <source>Quickly Unmount Removable Media</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="320"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="321"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../usbunmounter.cpp" line="322"/>
        <location filename="../usbunmounter.cpp" line="324"/>
        <source>License</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
